'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var helperPluginUtils = require('@babel/helper-plugin-utils');
var pluginProposalObjectRestSpread = _interopDefault(require('@babel/plugin-proposal-object-rest-spread'));
var pluginSyntaxDynamicImport = _interopDefault(require('@babel/plugin-syntax-dynamic-import'));
var pluginProposalDecorators = _interopDefault(require('@babel/plugin-proposal-decorators'));
var pluginProposalClassProperties = _interopDefault(require('@babel/plugin-proposal-class-properties'));
var pluginProposalPrivateMethods = _interopDefault(require('@babel/plugin-proposal-private-methods'));
var presetEnv = _interopDefault(require('@babel/preset-env'));
var presetReact = _interopDefault(require('@babel/preset-react'));
var presetTypeScript = _interopDefault(require('@babel/preset-typescript'));
var presetTypeScriptVue = _interopDefault(require('babel-preset-typescript-vue'));

var index = helperPluginUtils.declare((api, {
  vue = false,
  react = true,
  presetEnvSettings = {
    "modules": "auto",
    "useBuiltIns": "usage",
    "corejs": 3
  },
  presetReactSettings = {}
}) => {
  api.assertVersion(7);

  if (typeof vue !== "boolean") {
    throw new Error("vue must be a boolean, or undefined");
  }

  if (typeof presetEnvSettings !== "object") {
    throw new Error("presetEnvSettings must be an object, or undefined");
  }

  if (typeof presetReactSettings !== "object") {
    throw new Error("presetEnvSettings must be an object, or undefined");
  }

  const presets = [];
  presets.push(vue ? presetTypeScriptVue : presetTypeScript);
  presets.push([presetEnv, presetEnvSettings]);

  if (react) {
    presets.push([presetReact, presetReactSettings]);
  }

  return {
    "plugins": [pluginProposalObjectRestSpread, pluginSyntaxDynamicImport, [pluginProposalDecorators, {
      "legacy": true
    }], [pluginProposalClassProperties, {
      "loose": true
    }], [pluginProposalPrivateMethods, {
      "loose": true
    }]],
    presets
  };
});

module.exports = index;
